import {
  Checkbox,
  Form,
  Modal,
  Result,
  Typography,
  notification,
  Divider,
  Flex,
  Button,
} from "antd";
import { Constants } from "../../utils";
import { Trans, useTranslation } from "react-i18next";
import MyAppLogo from "../../Components/MyAppLogo";
import ReCAPTCHA from "react-google-recaptcha";
import { ForgotPassword, Login } from "./Login";
import SignUp from "./SignUp";
import { useNavigate } from "react-router-dom";

export const AuthenticationMethod = {
  LOGIN: 1,
  SIGN_UP: 2,
  FORGOT_PASSWORD: 3,
};

export default function Authentication({ method }) {
  const [notificationApi, notificationContextHolder] =
    notification.useNotification();

  return (
    <>
      {notificationContextHolder}

      <Modal
        open={true}
        mask={false}
        closable={false}
        centered
        keyboard={false}
        footer={null}
      >
        <div
          style={{
            display: "flex",
            justifyContent: "center",
          }}
        >
          <MyAppLogo height={80} />
        </div>

        {method === AuthenticationMethod.LOGIN ? (
          <Login notificationApi={notificationApi} />
        ) : method === AuthenticationMethod.SIGN_UP ? (
          <SignUp notificationApi={notificationApi} />
        ) : (
          <ForgotPassword notificationApi={notificationApi} />
        )}
      </Modal>
    </>
  );
}

export function MyRecaptcha({ recaptchaRef, recaptchaValueRef }) {
  const { t } = useTranslation();

  return (
    <Form.Item
      name="recaptcha"
      rules={[
        {
          required: true,
          message: t("common.inputRules.recaptchaRequired"),
        },
      ]}
    >
      <ReCAPTCHA
        ref={recaptchaRef}
        sitekey={process.env.REACT_APP_RECAPTCHA_SITE_KEY}
        onChange={(value) => (recaptchaValueRef.current = value)}
      />
    </Form.Item>
  );
}

export function RememberMeCheckbox() {
  const { t } = useTranslation();

  return (
    <Form.Item name="rememberMe" valuePropName="checked">
      <Checkbox>{t("authentication.rememberMe")}</Checkbox>
    </Form.Item>
  );
}

export function PrivacyPolicyCheckbox() {
  const { t } = useTranslation();

  const link = (
    <a href={Constants.PRIVACY_POLICY_URL} target="_blank" rel="noreferrer" />
  );

  return (
    <Form.Item
      name="privacyPolicy"
      valuePropName="checked"
      rules={[
        {
          required: true,
          message: t("common.inputRules.privacyPolicyRequired"),
        },
      ]}
    >
      <Checkbox>
        <Trans
          i18nKey="authentication.privacyPolicy"
          values={{ dataPrivacy: t("authentication.privacyPolicyLink") }}
          components={{ dataLink: link }}
        />
      </Checkbox>
    </Form.Item>
  );
}

export function PendingEmailVerification() {
  const { t } = useTranslation();

  return (
    <Result
      status="warning"
      title={t("authentication.signUp.pendingEmailVerification.title")}
      subTitle={t("authentication.signUp.pendingEmailVerification.description")}
    />
  );
}

export function MyLanguageSwitch() {
  const { t, i18n } = useTranslation();

  return (
    <>
      <Divider style={{ padding: 0, margin: 4 }} />

      <Flex justify="center">
        <Typography.Text style={{ color: "gray" }}>
          {t("authentication.languageSwitchTo")}{" "}
          <Button
            type="link"
            style={{ padding: 0 }}
            onClick={() =>
              i18n.changeLanguage(i18n.language === "en" ? "de" : "en")
            }
          >
            {i18n.language === "en" ? "Deutsch" : "English"}
          </Button>
        </Typography.Text>
      </Flex>
    </>
  );
}

/*
export function BackToZeitAdlerPricingOverview() {
  window.location.href = process.env.REACT_APP_ZEITADLER_HOMEPAGE_PRICING;
}
*/
