import { useParams } from "react-router-dom";
import MyModal from "../../Components/MyModal";
import {
  Button,
  ConfigProvider,
  Flex,
  Form,
  Result,
  Spin,
  notification,
} from "antd";
import { useEffect, useState } from "react";
import MyAppLogo from "../../Components/MyAppLogo";
import PageNotFound, { ButtonBackHome } from "../PageNotFound";
import {
  Constants,
  EncodeStringToBase64,
  myFetch,
  showInputsInvalidNotification,
  showPasswordIncorrectNotification,
} from "../../utils";
import { useTranslation } from "react-i18next";
import { RequestState } from "../../Components/MyRequestStateItem";
import { MyPasswordFormInput } from "../../Components/MyFormInputs";

export default function Verification() {
  const { state, emailVerificationId } = useParams();
  const { t } = useTranslation();
  const [notificationApi, notificationContextHolder] =
    notification.useNotification();
  const [form] = Form.useForm();

  const [isRequesting, setIsRequesting] = useState(RequestState.INIT);

  const ButtonToLogin = () => {
    return (
      <Button
        type="primary"
        onClick={() => {
          window.location.href = `${Constants.DASHBOARD_ADDRESS}${Constants.ROUTE_PATHS.AUTHENTICATION.LOGIN}`;
        }}
      >
        {t("verification.buttonToLogin")}
      </Button>
    );
  };

  const content = [
    {
      requesting: {
        title: t("verification.content.0.requesting.title"),
        extra: <Spin size="large" />,
      },
      success: {
        title: t("verification.content.0.success.title"),
        extra: <ButtonToLogin />,
      },
    },
    {
      init: {
        title: t("verification.content.1.init.title"),
        subTitle: t("verification.content.1.init.subTitle"),
        extra: (
          <Form form={form} layout="vertical" requiredMark={false}>
            <MyPasswordFormInput />

            <Button
              type="primary"
              htmlType="submit"
              block
              onClick={() => {
                form
                  .validateFields()
                  .then((values) => {
                    setIsRequesting(RequestState.REQUESTING);

                    sendVerifyRequest({
                      password: EncodeStringToBase64(values.password),
                    })
                      .then(() => setIsRequesting(RequestState.SUCCESS))
                      .catch(() => {
                        setIsRequesting(RequestState.INIT);
                        showPasswordIncorrectNotification(notificationApi, t);
                      });
                  })
                  .catch(() =>
                    showInputsInvalidNotification(notificationApi, t)
                  );
              }}
            >
              {t("common.button.confirm")}
            </Button>
          </Form>
        ),
      },
      requesting: {
        title: t("verification.content.1.requesting.title"),
        extra: <Spin size="large" />,
      },
      success: {
        title: t("verification.content.1.success.title"),
        extra: <ButtonToLogin />,
      },
    },
    {
      init: {
        title: t("verification.content.2.init.title"),
        subTitle: t("verification.content.2.init.subTitle"),
        extra: (
          <Form form={form} layout="vertical" requiredMark={false}>
            <MyPasswordFormInput newPassword />

            <Button
              type="primary"
              htmlType="submit"
              block
              onClick={() => {
                form
                  .validateFields()
                  .then((values) => {
                    setIsRequesting(RequestState.REQUESTING);

                    sendVerifyRequest({
                      password: EncodeStringToBase64(values.password),
                    })
                      .then(() => setIsRequesting(RequestState.SUCCESS))
                      .catch(() => {
                        setIsRequesting(RequestState.INIT);
                        showPasswordIncorrectNotification(notificationApi, t);
                      });
                  })
                  .catch(() =>
                    showInputsInvalidNotification(notificationApi, t)
                  );
              }}
            >
              {t("common.button.confirm")}
            </Button>
          </Form>
        ),
      },
      requesting: {
        title: t("verification.content.2.requesting.title"),
        extra: <Spin size="large" />,
      },
      success: {
        title: t("verification.content.2.success.title"),
        extra: <ButtonToLogin />,
      },
    },
  ];

  const parsedState = isNaN(state) ? 0 : parseInt(state);

  let elementContent;

  if (
    state === undefined ||
    emailVerificationId === undefined ||
    state > content.length - 1
  ) {
    elementContent = <PageNotFound useHref />;
  } else if (isRequesting === RequestState.INIT) {
    elementContent = (
      <Result
        status="info"
        title={content[parsedState].init?.title}
        subTitle={content[parsedState].init?.subTitle}
        extra={content[parsedState].init?.extra}
      />
    );
  } else if (isRequesting === RequestState.REQUESTING) {
    elementContent = (
      <Result
        status="info"
        title={content[parsedState].requesting?.title}
        subTitle={content[parsedState].requesting?.subTitle}
        extra={content[parsedState].requesting?.extra}
      />
    );
  } else if (isRequesting === RequestState.SUCCESS) {
    elementContent = (
      <Result
        status="success"
        title={content[parsedState].success?.title}
        subTitle={content[parsedState].success?.subTitle}
        extra={content[parsedState].success?.extra}
      />
    );
  } else if (isRequesting === RequestState.FAILED) {
    elementContent = (
      <Result
        status="error"
        title={t("verification.error.title")}
        subTitle={t("verification.error.description")}
        extra={<ButtonBackHome useHref />}
      />
    );
  } else {
    elementContent = <PageNotFound useHref />;
  }

  const sendVerifyRequest = (body) => {
    return myFetch({
      method: "POST",
      url: `/user/verify/${state}/${emailVerificationId}`,
      notificationApi: notificationApi,
      body: body,
      t: t,
    });
  };

  useEffect(() => {
    if (emailVerificationId === undefined || state === undefined) {
      setIsRequesting(RequestState.FAILED);
      return;
    }

    sendVerifyRequest()
      .then((res) => {
        // if an action by the user is required, do not change the state (e.g. for providing a new password)
        if (res.status !== undefined && res.status === "actionRequired") return;

        setIsRequesting(RequestState.SUCCESS);
      })
      .catch(() => setIsRequesting(RequestState.FAILED));
  }, []);

  return (
    <ConfigProvider
      theme={{
        token: {
          colorBgMask: "rgba(0, 0, 0, 0.0)",
        },
      }}
    >
      <MyModal isOpen={true} footer={null} closable={false}>
        {notificationContextHolder}

        <Flex justify="center">
          <MyAppLogo height={100} />
        </Flex>

        {elementContent}
      </MyModal>
    </ConfigProvider>
  );
}
